@@ -32,12 +32,12 @@ DISTRO_PRETTY_NAME = {
     'debian': 'Debian GNU/Linux 11 (bullseye)',
     'ubuntu': 'Ubuntu 20.04',
 }
-OPENSTACK_RELEASE = 'xena'
+OPENSTACK_RELEASE = 'yoga'
 
 # This is noarch repository so we will use it on all architectures
-DELOREAN = "https://trunk.rdoproject.org/centos8-xena/" \
+DELOREAN = "https://trunk.rdoproject.org/centos8-yoga/" \
     "consistent/delorean.repo"
-DELOREAN_DEPS = "https://trunk.rdoproject.org/centos8-xena/" \
+DELOREAN_DEPS = "https://trunk.rdoproject.org/centos8-yoga/" \
     "delorean-deps.repo"
 
 INSTALL_TYPE_CHOICES = ['binary', 'source']
@@ -58,6 +58,7 @@ _PROFILE_OPTS = [
                     'keepalived',
                     'kibana',
                     'kolla-toolbox',
+                    'letsencrypt',
                     'logstash',
                     'mariadb',
                     'memcached',
@@ -249,9 +250,7 @@ _CLI_OPTS = [
     cfg.BoolOpt('summary', default=True,
                 help='Show summary at the end of build'),
     cfg.BoolOpt('infra-rename', default=False,
-                help='Rename infrastructure images to infra'),
-    cfg.StrOpt('repos-yaml', default='',
-               help='Path to alternative repos.yaml file'),
+                help='Rename infrastructure images to infra')
 ]
 
 _BASE_OPTS = [
@@ -626,10 +625,6 @@ SOURCES = {
         'type': 'url',
         'location': ('$tarballs_base/openstack/vitrage/'
                      'vitrage-${openstack_branch}.tar.gz')},
-    'vmtp': {
-        'type': 'url',
-        'location': ('$tarballs_base/openstack/vmtp/'
-                     'vmtp-master.tar.gz')},
     'watcher-base': {
         'type': 'url',
         'location': ('$tarballs_base/openstack/watcher/'
@@ -824,7 +819,7 @@ USERS = {
         'uid': 42449,
         'gid': 42449,
     },
-    'vmtp-user': {
+    'vmtp-user': {  # unused user (vmtp dropped)
         'uid': 42450,
         'gid': 42450,
     },
@@ -952,11 +947,15 @@ USERS = {
     'proxysql-user': {
         'uid': 42487,
         'gid': 42487,
+    },
+    'letsencrypt-user': {
+        'uid': 42488,
+        'gid': 42488,
     }
 }
 
 
-def get_source_opts(type_=None, location=None, reference=None):
+def get_source_opts(type_=None, location=None, reference=None, enabled=True):
     return [cfg.StrOpt('type', choices=['local', 'git', 'url'],
                        default=type_,
                        help='Source location type'),
@@ -964,7 +963,9 @@ def get_source_opts(type_=None, location=None, reference=None):
                        help='The location for source install'),
             cfg.StrOpt('reference', default=reference,
                        help=('Git reference to pull, commit sha, tag '
-                             'or branch name'))]
+                             'or branch name')),
+            cfg.BoolOpt('enabled', default=enabled,
+                        help=('Whether the source is enabled'))]
 
 
 def get_user_opts(uid, gid, group):
@@ -991,7 +992,8 @@ def gen_all_source_opts():
         type_ = params['type']
         location = params['location']
         reference = params.get('reference')
-        yield name, get_source_opts(type_, location, reference)
+        enabled = params.get('enabled', True)
+        yield name, get_source_opts(type_, location, reference, enabled)
 
 
 def list_opts():
