@@ -367,6 +367,15 @@ class BuildTask(DockerTask):
 
         dest_archive = os.path.join(image.path, source['name'] + '-archive')
 
+        # NOTE(mgoddard): Change ownership of files to root:root. This
+        # avoids an issue introduced by the fix for git CVE-2022-24765,
+        # which breaks PBR when the source checkout is not owned by the
+        # user installing it. LP#1969096
+        def reset_userinfo(tarinfo):
+            tarinfo.uid = tarinfo.gid = 0
+            tarinfo.uname = tarinfo.gname = "root"
+            return tarinfo
+
         if source.get('type') == 'url':
             self.logger.debug("Getting archive from %s", source['source'])
             try:
@@ -411,15 +420,6 @@ class BuildTask(DockerTask):
                 image.status = Status.ERROR
                 return
 
-            # NOTE(mgoddard): Change ownership of files to root:root. This
-            # avoids an issue introduced by the fix for git CVE-2022-24765,
-            # which breaks PBR when the source checkout is not owned by the
-            # user installing it. LP#1969096
-            def reset_userinfo(tarinfo):
-                tarinfo.uid = tarinfo.gid = 0
-                tarinfo.uname = tarinfo.gname = "root"
-                return tarinfo
-
             with tarfile.open(dest_archive, 'w') as tar:
                 tar.add(clone_dir, arcname=os.path.basename(clone_dir),
                         filter=reset_userinfo)
@@ -430,7 +430,8 @@ class BuildTask(DockerTask):
             if os.path.isdir(source['source']):
                 with tarfile.open(dest_archive, 'w') as tar:
                     tar.add(source['source'],
-                            arcname=os.path.basename(source['source']))
+                            arcname=os.path.basename(source['source']),
+                            filter=reset_userinfo)
             else:
                 shutil.copyfile(source['source'], dest_archive)
 
@@ -663,6 +664,8 @@ class KollaWorker(object):
             self.debian_arch = 'amd64'
         self.images = list()
         self.openstack_release = conf.openstack_release
+        self.openstack_branch = conf.openstack_branch
+        self.openstack_branch_slashed = conf.openstack_branch_slashed
         self.docker_healthchecks = conf.docker_healthchecks
         rpm_setup_config = ([repo_file for repo_file in
                              conf.rpm_setup_config if repo_file is not None])
@@ -897,6 +900,9 @@ class KollaWorker(object):
                       'install_type': self.install_type,
                       'namespace': self.namespace,
                       'openstack_release': self.openstack_release,
+                      'openstack_branch': self.openstack_branch,
+                      'openstack_branch_slashed':
+                          self.openstack_branch_slashed,
                       'tag': self.tag,
                       'maintainer': self.maintainer,
                       'kolla_version': kolla_version,
